# -*- coding: utf-8 -*-

"""
Terminal.color
~~~~~~~~~~~~~~

Contains Variables with Color Codes to change the color in the Terminal (Windows)
"""

from ._background import background
from ._foreground import foreground
