# -*- coding: utf-8 -*-

"""
Maxi's Functions
~~~~~~~~~~~~~~~~

Contains all my Functions

"""

from .append_clipboard          import append_clipboard			as appendClipboard
from .better_color_input        import better_color_input       as betterColorInput
from .better_input              import better_input             as betterInput
from .better_print              import better_print             as betterPrint
from .color_input               import color_input              as colorInput
from .key_dict					import kdict					as kdict
from .kwargs_handler			import KWArgsHandler			as KWArgsHandler
from .output_stdout             import output_stdout            as outputStdout
from .terminal                  import Terminal                 as Terminal